# Grepy

A Python clone of [Grep](https://en.wikipedia.org/wiki/Grep).

## Install

You can install [Chuy](https://pypi.org/project/chuy) from PyPI like any other package:

```bash
pip install grepy
```

To get the last version:

```bash
pip install git+https:/github.com/UltiRequiem/grepy
```

If you use Linux, you may need to install this with sudo to
be able to access the command throughout your system.

### License

Grepy is licensed under the [MIT License](./LICENSE).
